@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2015-05-19'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $DATE = '2015-05-20'; # DATE
+our $VERSION = '0.68'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,13 +58,31 @@ sub _parse_json {
 
 sub _parse_yaml {
     no warnings 'once';
-    require YAML::XS;
+
+    state $yaml_xs_available = do {
+        if (eval { require YAML::XS; 1 }) {
+            1;
+        } else {
+            require YAML::Old;
+            0;
+        }
+    };
 
     my $str = shift;
 
     #local $YAML::Syck::ImplicitTyping = 1;
     my $res;
-    eval { $res = YAML::XS::Load($str) };
+    eval {
+        if ($yaml_xs_available) {
+            $res = YAML::XS::Load($str);
+        } else {
+            # YAML::Old is too strict, it requires "--- " header and newline
+            # ending
+            $str = "--- $str" unless $str =~ /\A--- /;
+            $str .= "\n" unless $str =~ /\n\z/;
+            $res = YAML::Old::Load($str);
+        }
+    };
     my $e = $@;
     return (!$e, $e, $res);
 }
@@ -979,7 +997,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-05-19.
+This document describes version 0.68 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-05-20.
 
 =head1 SYNOPSIS
 
